@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.functions_v1.services.cloud_functions_service import pagers
@@ -178,9 +180,9 @@ class CloudFunctionsServiceAsyncClient:
 
     async def list_functions(
         self,
-        request: functions.ListFunctionsRequest = None,
+        request: Union[functions.ListFunctionsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFunctionsAsyncPager:
@@ -188,7 +190,7 @@ class CloudFunctionsServiceAsyncClient:
         requested project.
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.ListFunctionsRequest`):
+            request (Union[google.cloud.functions_v1.types.ListFunctionsRequest, dict]):
                 The request object. Request for the `ListFunctions`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -246,10 +248,10 @@ class CloudFunctionsServiceAsyncClient:
 
     async def get_function(
         self,
-        request: functions.GetFunctionRequest = None,
+        request: Union[functions.GetFunctionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> functions.CloudFunction:
@@ -257,7 +259,7 @@ class CloudFunctionsServiceAsyncClient:
         requested project.
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.GetFunctionRequest`):
+            request (Union[google.cloud.functions_v1.types.GetFunctionRequest, dict]):
                 The request object. Request for the `GetFunction`
                 method.
             name (:class:`str`):
@@ -330,11 +332,11 @@ class CloudFunctionsServiceAsyncClient:
 
     async def create_function(
         self,
-        request: functions.CreateFunctionRequest = None,
+        request: Union[functions.CreateFunctionRequest, dict] = None,
         *,
         location: str = None,
         function: functions.CloudFunction = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -343,7 +345,7 @@ class CloudFunctionsServiceAsyncClient:
         operation will return ``ALREADY_EXISTS`` error.
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.CreateFunctionRequest`):
+            request (Union[google.cloud.functions_v1.types.CreateFunctionRequest, dict]):
                 The request object. Request for the `CreateFunction`
                 method.
             location (:class:`str`):
@@ -423,17 +425,17 @@ class CloudFunctionsServiceAsyncClient:
 
     async def update_function(
         self,
-        request: functions.UpdateFunctionRequest = None,
+        request: Union[functions.UpdateFunctionRequest, dict] = None,
         *,
         function: functions.CloudFunction = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates existing function.
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.UpdateFunctionRequest`):
+            request (Union[google.cloud.functions_v1.types.UpdateFunctionRequest, dict]):
                 The request object. Request for the `UpdateFunction`
                 method.
             function (:class:`google.cloud.functions_v1.types.CloudFunction`):
@@ -517,10 +519,10 @@ class CloudFunctionsServiceAsyncClient:
 
     async def delete_function(
         self,
-        request: functions.DeleteFunctionRequest = None,
+        request: Union[functions.DeleteFunctionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -530,7 +532,7 @@ class CloudFunctionsServiceAsyncClient:
         function.
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.DeleteFunctionRequest`):
+            request (Union[google.cloud.functions_v1.types.DeleteFunctionRequest, dict]):
                 The request object. Request for the `DeleteFunction`
                 method.
             name (:class:`str`):
@@ -622,11 +624,11 @@ class CloudFunctionsServiceAsyncClient:
 
     async def call_function(
         self,
-        request: functions.CallFunctionRequest = None,
+        request: Union[functions.CallFunctionRequest, dict] = None,
         *,
         name: str = None,
         data: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> functions.CallFunctionResponse:
@@ -636,7 +638,7 @@ class CloudFunctionsServiceAsyncClient:
         Limits <https://cloud.google.com/functions/quotas#rate_limits>`__.
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.CallFunctionRequest`):
+            request (Union[google.cloud.functions_v1.types.CallFunctionRequest, dict]):
                 The request object. Request for the `CallFunction`
                 method.
             name (:class:`str`):
@@ -704,9 +706,9 @@ class CloudFunctionsServiceAsyncClient:
 
     async def generate_upload_url(
         self,
-        request: functions.GenerateUploadUrlRequest = None,
+        request: Union[functions.GenerateUploadUrlRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> functions.GenerateUploadUrlResponse:
@@ -740,7 +742,7 @@ class CloudFunctionsServiceAsyncClient:
         -  ``Authorization: Bearer YOUR_TOKEN``
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.GenerateUploadUrlRequest`):
+            request (Union[google.cloud.functions_v1.types.GenerateUploadUrlRequest, dict]):
                 The request object. Request of `GenerateSourceUploadUrl`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -778,9 +780,9 @@ class CloudFunctionsServiceAsyncClient:
 
     async def generate_download_url(
         self,
-        request: functions.GenerateDownloadUrlRequest = None,
+        request: Union[functions.GenerateDownloadUrlRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> functions.GenerateDownloadUrlResponse:
@@ -793,7 +795,7 @@ class CloudFunctionsServiceAsyncClient:
         control/signed-urls
 
         Args:
-            request (:class:`google.cloud.functions_v1.types.GenerateDownloadUrlRequest`):
+            request (Union[google.cloud.functions_v1.types.GenerateDownloadUrlRequest, dict]):
                 The request object. Request of `GenerateDownloadUrl`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -831,9 +833,9 @@ class CloudFunctionsServiceAsyncClient:
 
     async def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
@@ -841,7 +843,7 @@ class CloudFunctionsServiceAsyncClient:
         function. Replaces any existing policy.
 
         Args:
-            request (:class:`google.iam.v1.iam_policy_pb2.SetIamPolicyRequest`):
+            request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -937,9 +939,9 @@ class CloudFunctionsServiceAsyncClient:
 
     async def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
@@ -948,7 +950,7 @@ class CloudFunctionsServiceAsyncClient:
         not have a policy set.
 
         Args:
-            request (:class:`google.iam.v1.iam_policy_pb2.GetIamPolicyRequest`):
+            request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1044,9 +1046,9 @@ class CloudFunctionsServiceAsyncClient:
 
     async def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
@@ -1055,7 +1057,7 @@ class CloudFunctionsServiceAsyncClient:
         return an empty set of permissions, not a NOT_FOUND error.
 
         Args:
-            request (:class:`google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest`):
+            request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
                 `TestIamPermissions` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
